@@ -14,8 +14,7 @@ Requirements:
 
 Usage:
 ```python
-from acb.depends import depends
-from acb.adapters import import_adapter
+from acb.depends import Inject, depends
 
 htmy = depends.get("htmy")
 
@@ -33,23 +32,71 @@ Created: 2025-01-13
 import asyncio
 import typing as t
 from contextlib import suppress
+from enum import Enum
+from typing import TYPE_CHECKING, Any
 from uuid import UUID
 
-from acb.adapters import AdapterStatus, get_adapter, import_adapter, root_path
+# Handle imports with fallback for different ACB versions
+# Import all names in a single try-except block
+imports_successful = False
+try:
+    from acb.adapters import AdapterStatus as _AdapterStatus
+    from acb.adapters import get_adapter as _get_adapter
+    from acb.adapters import import_adapter as _import_adapter
+    from acb.adapters import root_path as _root_path
+
+    imports_successful = True
+except ImportError:
+    _AdapterStatus = None
+    _get_adapter = None
+    _import_adapter = None
+    _root_path = None
+
+# Assign the imported names or fallbacks
+if imports_successful:
+    AdapterStatus = _AdapterStatus
+    get_adapter = _get_adapter
+    import_adapter = _import_adapter
+    root_path = _root_path
+else:
+    # Define fallbacks
+    class _FallbackAdapterStatus(Enum):
+        ALPHA = "alpha"
+        BETA = "beta"
+        STABLE = "stable"
+        DEPRECATED = "deprecated"
+        EXPERIMENTAL = "experimental"
+
+    AdapterStatus = _FallbackAdapterStatus
+    get_adapter = None
+    import_adapter = None
+    root_path = None
 from acb.debug import debug
 from acb.depends import depends
 from anyio import Path as AsyncPath
 from starlette.responses import HTMLResponse
 
 from ._base import TemplatesBase, TemplatesBaseSettings
+from ._htmy_components import (
+    AdvancedHTMYComponentRegistry,
+    ComponentLifecycleManager,
+    ComponentMetadata,
+    ComponentRenderError,
+    ComponentStatus,
+    ComponentType,
+)
+
+if TYPE_CHECKING:
+    from fastblocks.actions.sync.strategies import SyncDirection, SyncStrategy
+    from fastblocks.actions.sync.templates import sync_templates
 
 try:
     from fastblocks.actions.sync.strategies import SyncDirection, SyncStrategy
     from fastblocks.actions.sync.templates import sync_templates
 except ImportError:
-    sync_templates = None
-    SyncDirection = None
-    SyncStrategy = None
+    sync_templates: t.Callable[..., t.Any] | None = None  # type: ignore[no-redef]
+    SyncDirection: type[Enum] | None = None  # type: ignore[no-redef]
+    SyncStrategy: type[object] | None = None  # type: ignore[no-redef]
 
 try:
     Cache, Storage, Models = import_adapter()
@@ -118,13 +165,14 @@ class HTMYComponentRegistry:
             cache_key = self.get_cache_key(component_path)
             cached = await self.cache.get(cache_key)
             if cached:
-                return cached.decode()
+                return t.cast(str, cached.decode())
         return None
 
     async def _get_cached_bytecode(self, component_path: AsyncPath) -> bytes | None:
         if self.cache is not None:
             cache_key = self.get_cache_key(component_path, "bytecode")
-            return await self.cache.get(cache_key)
+            result = await self.cache.get(cache_key)
+            return t.cast(Response, result)
         return None
 
     async def _sync_component_file(
@@ -202,39 +250,102 @@ class HTMYComponentRegistry:
     async def get_component_class(self, component_name: str) -> t.Any:
         if component_name in self._component_cache:
             return self._component_cache[component_name]
+
         source, component_path = await self.get_component_source(component_name)
         cached_bytecode = await self._get_cached_bytecode(component_path)
+
+        # Try to load from cached bytecode first
+        if cached_bytecode:
+            component_class = await self._load_from_cached_bytecode(
+                cached_bytecode, source, component_path, component_name
+            )
+            if component_class:
+                return component_class
+
+        # Otherwise, load from source
+        return await self._load_from_source(source, component_path, component_name)
+
+    async def _load_from_cached_bytecode(
+        self, cached_bytecode, source, component_path, component_name
+    ):
+        """Attempt to load component class from cached bytecode."""
         try:
-            if cached_bytecode:
-                try:
-                    import pickle
+            # Instead of using pickle, we'll compile the source directly
+            # Pickle is a security risk as mentioned in the semgrep error
+            compile(source, str(component_path), "exec")
+            # Create a module-like namespace to execute the compiled code
+            import importlib.util
+            import os
+            import tempfile
+
+            # Create a temporary module to safely load the component
+            with tempfile.NamedTemporaryFile(mode="w", suffix=".py", delete=False) as f:
+                f.write(source)
+                temp_module_path = f.name
 
-                    component_class = pickle.loads(cached_bytecode)
-                    self._component_cache[component_name] = component_class
-                    return component_class
-                except Exception as e:
-                    debug(f"Failed to load cached bytecode for {component_name}: {e}")
-            namespace = {}
-            compiled_code = compile(source, str(component_path), "exec")
-            exec(compiled_code, namespace)
-            component_class = None
-            for obj in namespace.values():
-                if hasattr(obj, "htmy") and callable(getattr(obj, "htmy")):
-                    component_class = obj
-                    break
-            if component_class is None:
-                raise ComponentCompilationError(
-                    f"No valid component class found in {component_path}"
-                )
-            self._component_cache[component_name] = component_class
             try:
-                import pickle
+                spec = importlib.util.spec_from_file_location(
+                    component_path.stem, temp_module_path
+                )
+                if spec is None or spec.loader is None:
+                    raise ComponentCompilationError(
+                        f"Could not load module from {component_path}"
+                    )
 
-                bytecode = pickle.dumps(component_class)
-                await self._cache_component_bytecode(component_path, bytecode)
-            except Exception as e:
-                debug(f"Failed to cache bytecode for {component_name}: {e}")
+                module = importlib.util.module_from_spec(spec)
+                spec.loader.exec_module(module)
 
+                component_class = None
+                for obj in vars(module).values():
+                    if hasattr(obj, "htmy") and callable(getattr(obj, "htmy")):
+                        component_class = obj
+                        break
+            finally:
+                # Clean up the temporary file
+                os.unlink(temp_module_path)
+
+            # Cache the compiled form instead of pickle-able bytecode
+            self._component_cache[component_name] = component_class
+            return component_class
+        except Exception as e:
+            debug(f"Failed to load cached bytecode for {component_name}: {e}")
+            return None
+
+    async def _load_from_source(self, source, component_path, component_name):
+        """Load component class from source file."""
+        try:
+            # Import and analyze component safely
+            import importlib.util
+            import os
+            import tempfile
+
+            # Create a temporary module to safely load the component
+            with tempfile.NamedTemporaryFile(mode="w", suffix=".py", delete=False) as f:
+                f.write(source)
+                temp_module_path = f.name
+
+            try:
+                spec = importlib.util.spec_from_file_location(
+                    component_path.stem, temp_module_path
+                )
+                if spec is None or spec.loader is None:
+                    raise ComponentCompilationError(
+                        f"Could not load module from {component_path}"
+                    )
+
+                module = importlib.util.module_from_spec(spec)
+                spec.loader.exec_module(module)
+
+                component_class = None
+                for obj in vars(module).values():
+                    if hasattr(obj, "htmy") and callable(getattr(obj, "htmy")):
+                        component_class = obj
+                        break
+            finally:
+                # Clean up the temporary file
+                os.unlink(temp_module_path)
+
+            self._component_cache[component_name] = component_class
             return component_class
         except Exception as e:
             raise ComponentCompilationError(
@@ -247,14 +358,20 @@ class HTMYTemplatesSettings(TemplatesBaseSettings):
     cache_timeout: int = 300
     enable_bidirectional: bool = True
     debug_components: bool = False
+    enable_hot_reload: bool = True
+    enable_lifecycle_hooks: bool = True
+    enable_component_validation: bool = True
+    enable_advanced_registry: bool = True
 
 
 class HTMYTemplates(TemplatesBase):
     def __init__(self, **kwargs: t.Any) -> None:
         super().__init__(**kwargs)
         self.htmy_registry: HTMYComponentRegistry | None = None
+        self.advanced_registry: AdvancedHTMYComponentRegistry | None = None
         self.component_searchpaths: list[AsyncPath] = []
         self.jinja_templates: t.Any = None
+        self.settings = HTMYTemplatesSettings(**kwargs)
 
     async def get_component_searchpaths(self, app_adapter: t.Any) -> list[AsyncPath]:
         searchpaths = []
@@ -280,8 +397,9 @@ class HTMYTemplates(TemplatesBase):
         return searchpaths
 
     async def _init_htmy_registry(self) -> None:
-        if self.htmy_registry is not None:
+        if self.htmy_registry is not None and self.advanced_registry is not None:
             return
+
         app_adapter = get_adapter("app")
         if app_adapter is None:
             try:
@@ -290,7 +408,22 @@ class HTMYTemplates(TemplatesBase):
                 from types import SimpleNamespace
 
                 app_adapter = SimpleNamespace(name="app", category="app")
+
         self.component_searchpaths = await self.get_component_searchpaths(app_adapter)
+
+        # Initialize advanced registry if enabled
+        if self.settings.enable_advanced_registry:
+            self.advanced_registry = AdvancedHTMYComponentRegistry(
+                searchpaths=self.component_searchpaths,
+                cache=self.cache,
+                storage=self.storage,
+            )
+
+            # Configure hot reload
+            if self.settings.enable_hot_reload:
+                self.advanced_registry.enable_hot_reload()
+
+        # Keep legacy registry for backward compatibility
         self.htmy_registry = HTMYComponentRegistry(
             searchpaths=self.component_searchpaths,
             cache=self.cache,
@@ -326,7 +459,65 @@ class HTMYTemplates(TemplatesBase):
         if self.htmy_registry is None:
             await self._init_htmy_registry()
 
-        return await self.htmy_registry.get_component_class(component_name)
+        if self.htmy_registry is not None:
+            return await self.htmy_registry.get_component_class(component_name)
+        raise ComponentNotFound(
+            f"Component registry not initialized for '{component_name}'"
+        )
+
+    async def render_component_advanced(
+        self,
+        request: t.Any,
+        component: str,
+        context: dict[str, t.Any] | None = None,
+        status_code: int = 200,
+        headers: dict[str, str] | None = None,
+        **kwargs: t.Any,
+    ) -> HTMLResponse:
+        """Render component using advanced registry with lifecycle management."""
+        if context is None:
+            context = {}
+        if headers is None:
+            headers = {}
+
+        if self.advanced_registry is None:
+            await self._init_htmy_registry()
+
+        if self.advanced_registry is None:
+            raise ComponentRenderError(
+                f"Advanced registry not initialized for '{component}'"
+            )
+
+        try:
+            # Add kwargs to context
+            enhanced_context = context | kwargs
+
+            rendered_content = (
+                await self.advanced_registry.render_component_with_lifecycle(
+                    component, enhanced_context, request
+                )
+            )
+
+            return HTMLResponse(
+                content=rendered_content,
+                status_code=status_code,
+                headers=headers,
+            )
+
+        except Exception as e:
+            error_content = (
+                f"<html><body>Component {component} error: {e}</body></html>"
+            )
+            if self.settings.debug_components:
+                import traceback
+
+                error_content = f"<html><body><h3>Component {component} error:</h3><pre>{traceback.format_exc()}</pre></body></html>"
+
+            return HTMLResponse(
+                content=error_content,
+                status_code=500,
+                headers=headers,
+            )
 
     async def render_component(
         self,
@@ -342,9 +533,23 @@ class HTMYTemplates(TemplatesBase):
         if headers is None:
             headers = {}
 
+        # Use advanced registry if available and enabled
+        if (
+            self.settings.enable_advanced_registry
+            and self.advanced_registry is not None
+        ):
+            return await self.render_component_advanced(
+                request, component, context, status_code, headers, **kwargs
+            )
+
         if self.htmy_registry is None:
             await self._init_htmy_registry()
 
+        if self.htmy_registry is None:
+            raise ComponentNotFound(
+                f"Component registry not initialized for '{component}'"
+            )
+
         try:
             component_class = await self.htmy_registry.get_component_class(component)
 
@@ -391,7 +596,7 @@ class HTMYTemplates(TemplatesBase):
             if context is None:
                 context = {}
 
-            template_context = {**context, **kwargs}
+            template_context = context | kwargs
 
             if self.jinja_templates and hasattr(self.jinja_templates, "app"):
                 try:
@@ -400,7 +605,7 @@ class HTMYTemplates(TemplatesBase):
                         rendered = await template.render(template_context)
                     else:
                         rendered = template.render(template_context)
-                    return rendered
+                    return t.cast(str, rendered)
                 except Exception as e:
                     debug(
                         f"Failed to render template '{template_name}' in HTMY component: {e}"
@@ -414,6 +619,86 @@ class HTMYTemplates(TemplatesBase):
 
         return render_template
 
+    async def discover_components(self) -> dict[str, ComponentMetadata]:
+        """Discover all components and return metadata."""
+        if self.advanced_registry is None:
+            await self._init_htmy_registry()
+
+        if self.advanced_registry is not None:
+            return await self.advanced_registry.discover_components()
+
+        # Fallback to basic discovery
+        components = {}
+        if self.htmy_registry is not None:
+            discovered = await self.htmy_registry.discover_components()
+            for name, path in discovered.items():
+                components[name] = ComponentMetadata(
+                    name=name,
+                    path=path,
+                    type=ComponentType.BASIC,
+                    status=ComponentStatus.DISCOVERED,
+                )
+        return components
+
+    async def scaffold_component(
+        self,
+        name: str,
+        component_type: ComponentType = ComponentType.DATACLASS,
+        props: dict[str, type] | None = None,
+        htmx_enabled: bool = False,
+        endpoint: str = "",
+        trigger: str = "click",
+        target: str = "#content",
+        children: list[str] | None = None,
+        target_path: AsyncPath | None = None,
+    ) -> AsyncPath:
+        """Scaffold a new component."""
+        if self.advanced_registry is None:
+            await self._init_htmy_registry()
+
+        if self.advanced_registry is None:
+            raise ComponentRenderError(
+                "Advanced registry not available for scaffolding"
+            )
+
+        kwargs: dict[str, Any] = {}
+        if props:
+            kwargs["props"] = props
+        if htmx_enabled:
+            kwargs["htmx_enabled"] = True
+        if endpoint:
+            kwargs["endpoint"] = endpoint
+            kwargs["trigger"] = trigger
+            kwargs["target"] = target
+        if children:
+            kwargs["children"] = children
+
+        return await self.advanced_registry.scaffold_component(
+            name, component_type, target_path, **kwargs
+        )
+
+    async def validate_component(self, component_name: str) -> ComponentMetadata:
+        """Validate a specific component."""
+        components = await self.discover_components()
+        if component_name not in components:
+            raise ComponentNotFound(f"Component '{component_name}' not found")
+
+        return components[component_name]
+
+    def get_lifecycle_manager(self) -> ComponentLifecycleManager | None:
+        """Get the component lifecycle manager."""
+        if self.advanced_registry is not None:
+            return self.advanced_registry.lifecycle_manager
+        return None
+
+    def register_lifecycle_hook(
+        self, event: str, callback: t.Callable[..., Any]
+    ) -> None:
+        """Register a lifecycle hook."""
+        lifecycle_manager = self.get_lifecycle_manager()
+        if lifecycle_manager is not None:
+            lifecycle_manager.register_hook(event, callback)
+
     def _create_block_renderer(self, request: t.Any = None) -> t.Callable[..., t.Any]:
         async def render_block(
             block_name: str, context: dict[str, t.Any] | None = None, **kwargs: t.Any
@@ -421,7 +706,7 @@ class HTMYTemplates(TemplatesBase):
             if context is None:
                 context = {}
 
-            block_context = {**context, **kwargs}
+            block_context = context | kwargs
 
             if (
                 self.jinja_templates
@@ -439,7 +724,7 @@ class HTMYTemplates(TemplatesBase):
                         rendered = self.jinja_templates.app.render_block(
                             block_name, block_context
                         )
-                    return rendered
+                    return t.cast(str, rendered)
                 except Exception as e:
                     debug(
                         f"Failed to render block '{block_name}' in HTMY component: {e}"
@@ -490,7 +775,12 @@ class HTMYTemplates(TemplatesBase):
 
 
 MODULE_ID = UUID("01937d86-e1f2-7890-abcd-ef1234567890")
-MODULE_STATUS = AdapterStatus.STABLE
+MODULE_STATUS = AdapterStatus.STABLE if AdapterStatus is not None else None
+
+TemplatesSettings = HTMYTemplatesSettings
+Templates = HTMYTemplates
 
 with suppress(Exception):
-    depends.set(HTMYTemplates)
+    depends.set(Templates, "htmy")
+
+__all__ = ["Templates", "TemplatesSettings", "HTMYTemplatesSettings", "HTMYTemplates"]
