@@ -17,7 +17,7 @@ Requirements:
 
 Usage:
 ```python
-from acb.depends import depends
+from acb.depends import Inject, depends
 from acb.adapters import import_adapter
 
 templates = depends.get("templates")
@@ -48,6 +48,16 @@ from uuid import UUID
 from acb.adapters import AdapterStatus, get_adapter, import_adapter
 from acb.config import Config
 from acb.debug import debug
+
+# Import event tracking decorator (with fallback if unavailable)
+try:
+    from ._events_wrapper import track_template_render
+except ImportError:
+    # Fallback no-op decorator if events integration unavailable
+    def track_template_render(func: t.Callable[..., t.Any]) -> t.Callable[..., t.Any]:
+        return func
+
+
 from acb.depends import depends
 from anyio import Path as AsyncPath
 from jinja2 import TemplateNotFound
@@ -56,17 +66,11 @@ from jinja2.ext import debug as jinja_debug
 from jinja2_async_environment.bccache import AsyncRedisBytecodeCache
 from jinja2_async_environment.loaders import AsyncBaseLoader, SourceType
 from starlette_async_jinja import AsyncJinja2Templates
+from fastblocks.actions.sync.strategies import SyncDirection, SyncStrategy
+from fastblocks.actions.sync.templates import sync_templates
 
 from ._base import TemplatesBase, TemplatesBaseSettings
 
-try:
-    from fastblocks.actions.sync.strategies import SyncDirection, SyncStrategy
-    from fastblocks.actions.sync.templates import sync_templates
-except ImportError:
-    sync_templates = None
-    SyncDirection = None
-    SyncStrategy = None
-
 try:
     Cache, Storage, Models = import_adapter()
 except Exception:
@@ -102,9 +106,9 @@ def _apply_template_replacements(source: bytes, deployed: bool = False) -> bytes
 
 
 class BaseTemplateLoader(AsyncBaseLoader):
-    config: Config = depends()
-    cache: Cache = depends()
-    storage: Storage = depends()
+    config: t.Any = None
+    cache: t.Any = None
+    storage: t.Any = None
 
     def __init__(
         self,
@@ -241,7 +245,7 @@ class LoaderProtocol(t.Protocol):
 class FileSystemLoader(BaseTemplateLoader):
     async def _check_storage_exists(self, storage_path: AsyncPath) -> bool:
         if self.storage is not None:
-            return await self.storage.templates.exists(storage_path)
+            return t.cast(bool, await self.storage.templates.exists(storage_path))
         return False
 
     async def _sync_template_file(
@@ -440,7 +444,11 @@ class StorageLoader(BaseTemplateLoader):
                     return int(fs_stat.st_mtime) == local_mtime
                 else:
                     storage_stat = await self.storage.templates.stat(storage_path)
-                    return round(storage_stat.get("mtime").timestamp()) == local_mtime
+                    mtime = storage_stat.get("mtime")
+                    if hasattr(mtime, "timestamp"):
+                        timestamp = t.cast(float, mtime.timestamp())
+                        return round(timestamp) == local_mtime
+                    return False
 
             return (resp.decode(), str(storage_path), uptodate)
         except (FileNotFoundError, AttributeError):
@@ -482,11 +490,11 @@ class RedisLoader(BaseTemplateLoader):
     async def list_templates_async(self) -> list[str]:
         found: list[str] = []
         for ext in ("html", "css", "js"):
-            scan_result = (
+            scan_result: t.Any = (
                 await self.cache.scan(f"*.{ext}") if self.cache is not None else []
             )
             if hasattr(scan_result, "__aiter__"):
-                async for k in scan_result:  # type: ignore
+                async for k in scan_result:
                     found.append(k)
             else:
                 found.extend(scan_result)
@@ -640,7 +648,7 @@ class TemplatesSettings(TemplatesBaseSettings):
     def __init__(self, **data: t.Any) -> None:
         from pydantic import BaseModel
 
-        BaseModel.__init__(self, **data)
+        BaseModel.__init__(self, **data)  # type: ignore[arg-type]
         if not hasattr(self, "cache_timeout"):
             self.cache_timeout = 300
         try:
@@ -666,7 +674,7 @@ class Templates(TemplatesBase):
         if app_adapter is not None:
             return app_adapter
         with suppress(Exception):
-            app_adapter = depends.get("app")
+            app_adapter = depends.get_sync("app")
             if app_adapter is not None:
                 return app_adapter
 
@@ -678,7 +686,11 @@ class Templates(TemplatesBase):
             import asyncio
 
             loop = asyncio.get_event_loop()
-            if hasattr(self, "_admin_cache") and hasattr(self, "admin_searchpaths"):
+            if (
+                hasattr(self, "_admin_cache")
+                and hasattr(self, "admin_searchpaths")
+                and self.admin_searchpaths is not None
+            ):
                 debug("Initializing admin templates environment")
                 self._admin = loop.run_until_complete(
                     self.init_envs(
@@ -720,7 +732,6 @@ class Templates(TemplatesBase):
         debug(jinja_loaders)
         return ChoiceLoader(jinja_loaders)
 
-    @depends.inject
     async def init_envs(
         self,
         template_paths: list[AsyncPath],
@@ -762,9 +773,11 @@ class Templates(TemplatesBase):
             templates.env.loader = literal_eval(self.config.templates.loader)
         for delimiter, value in self.config.templates.delimiters.items():
             setattr(templates.env, delimiter, value)
-        templates.env.globals["config"] = self.config  # type: ignore[assignment]
-        templates.env.globals["render_block"] = templates.render_block  # type: ignore[assignment]
-        templates.env.globals["render_component"] = self._get_htmy_component_renderer()  # type: ignore[assignment]
+        # Type cast globals dict to avoid assignment type errors
+        globals_dict: dict[str, t.Any] = templates.env.globals  # type: ignore[assignment]
+        globals_dict["config"] = self.config
+        globals_dict["render_block"] = templates.render_block
+        globals_dict["render_component"] = self._get_htmy_component_renderer()
         if admin:
             try:
                 from sqladmin.helpers import (  # type: ignore[import-not-found,import-untyped]
@@ -772,13 +785,13 @@ class Templates(TemplatesBase):
                 )
             except ImportError:
                 get_object_identifier = str
-            templates.env.globals["min"] = min  # type: ignore[assignment]
-            templates.env.globals["zip"] = zip  # type: ignore[assignment]
-            templates.env.globals["admin"] = self  # type: ignore[assignment]
-            templates.env.globals["is_list"] = lambda x: isinstance(x, list)  # type: ignore[assignment]
-            templates.env.globals["get_object_identifier"] = get_object_identifier  # type: ignore[assignment]
+            globals_dict["min"] = min
+            globals_dict["zip"] = zip
+            globals_dict["admin"] = self
+            globals_dict["is_list"] = lambda x: isinstance(x, list)
+            globals_dict["get_object_identifier"] = get_object_identifier
         for k, v in self.config.templates.globals.items():
-            templates.env.globals[k] = v  # type: ignore[assignment]
+            globals_dict[k] = v
         return templates
 
     def _resolve_cache(self, cache: t.Any | None) -> t.Any | None:
@@ -814,10 +827,11 @@ class Templates(TemplatesBase):
                     "template",
                     "test",
                 ):
-                    await cache.clear(namespace)
+                    if cache is not None:
+                        await cache.clear(namespace)
                 self.logger.debug("Template caches cleared")
                 with suppress(Exception):
-                    htmy_adapter = depends.get("htmy")
+                    htmy_adapter = await depends.get("htmy")
                     if htmy_adapter:
                         await htmy_adapter.clear_component_cache()
                         self.logger.debug("HTMY component caches cleared via adapter")
@@ -831,7 +845,7 @@ class Templates(TemplatesBase):
             **kwargs: t.Any,
         ) -> str:
             try:
-                htmy_adapter = depends.get("htmy")
+                htmy_adapter = await depends.get("htmy")
                 if htmy_adapter:
                     htmy_adapter.jinja_templates = self
 
@@ -895,6 +909,8 @@ class Templates(TemplatesBase):
         parser = HTMLParser()
         parser.feed(html)
         soup = parser.get_starttag_text()
+        if soup is None:
+            return None
         attr_pattern = _get_attr_pattern(attr)
         _attr = f"{attr}="
         for s in soup.split():
@@ -910,6 +926,7 @@ class Templates(TemplatesBase):
                 else:
                     env.filters[name] = filter_func
 
+    @track_template_render
     async def render_template(
         self,
         request: t.Any,
@@ -940,6 +957,7 @@ class Templates(TemplatesBase):
             headers=headers,
         )
 
+    @track_template_render
     async def render_component(
         self,
         request: t.Any,
@@ -950,7 +968,7 @@ class Templates(TemplatesBase):
         **kwargs: t.Any,
     ) -> t.Any:
         try:
-            htmy_adapter = depends.get("htmy")
+            htmy_adapter = await depends.get("htmy")
             if htmy_adapter:
                 htmy_adapter.jinja_templates = self
                 return await htmy_adapter.render_component(
@@ -1017,3 +1035,5 @@ MODULE_STATUS = AdapterStatus.STABLE
 
 with suppress(Exception):
     depends.set(Templates)
+
+__all__ = ["Templates", "TemplatesSettings"]
