@@ -1,16 +1,17 @@
+import asyncio
 import base64
 import email.utils
-import hashlib
 import re
 import sys
 import time
 import typing as t
 from collections.abc import Iterable, Sequence
+from contextlib import suppress
 from dataclasses import dataclass
 from functools import partial
-from threading import local
 from urllib.request import parse_http_list
 
+from acb.actions.hash import hash
 from starlette.datastructures import URL, Headers, MutableHeaders
 from starlette.requests import Request
 from starlette.responses import Response
@@ -31,21 +32,11 @@ def _safe_log(logger: t.Any, level: str, message: str) -> None:
 
 _CacheClass = None
 
-_hasher_pool = local()
-
 _str_encode = str.encode
 _base64_encodebytes = base64.encodebytes
 _base64_decodebytes = base64.decodebytes
 
 
-def _get_hasher():
-    if not hasattr(_hasher_pool, "hasher"):
-        _hasher_pool.hasher = hashlib.md5(usedforsecurity=False)
-    else:
-        _hasher_pool.hasher.__init__(usedforsecurity=False)
-    return _hasher_pool.hasher
-
-
 def get_cache() -> t.Any:
     global _CacheClass
     if _CacheClass is None:
@@ -91,6 +82,26 @@ class Rule:
     ttl: float | None = None
 
 
+def _check_rule_match(match: list[str | re.Pattern[str]], path: str) -> bool:
+    """Check if any rule matches the request path."""
+    for item in match:
+        if isinstance(item, re.Pattern):
+            if item.match(path):
+                return True
+        elif item in ("*", path):
+            return True
+    return False
+
+
+def _check_response_status_match(rule: Rule, response: Response) -> bool:
+    """Check if response status code matches the rule."""
+    if rule.status is not None:
+        statuses = [rule.status] if isinstance(rule.status, int) else rule.status
+        if response.status_code not in statuses:
+            return False
+    return True
+
+
 class CacheRules:
     @staticmethod
     def request_matches_rule(rule: Rule, *, request: Request) -> bool:
@@ -99,13 +110,7 @@ class CacheRules:
             if isinstance(rule.match, str | re.Pattern)
             else list(rule.match)
         )
-        for item in match:
-            if isinstance(item, re.Pattern):
-                if item.match(request.url.path):
-                    return True
-            elif item in ("*", request.url.path):
-                return True
-        return False
+        return _check_rule_match(match, request.url.path)
 
     @staticmethod
     def response_matches_rule(
@@ -114,13 +119,11 @@ class CacheRules:
         request: Request,
         response: Response,
     ) -> bool:
+        # First check if request matches the rule
         if not CacheRules.request_matches_rule(rule, request=request):
             return False
-        if rule.status is not None:
-            statuses = [rule.status] if isinstance(rule.status, int) else rule.status
-            if response.status_code not in statuses:
-                return False
-        return True
+        # Then check if response status matches
+        return _check_response_status_match(rule, response)
 
     @staticmethod
     def get_rule_matching_request(
@@ -158,20 +161,14 @@ class CacheRules:
         )
 
 
-def request_matches_rule(rule: Rule, *, request: Request) -> bool:
-    return CacheRules.request_matches_rule(rule, request=request)
-
-
-def response_matches_rule(rule: Rule, *, request: Request, response: Response) -> bool:
-    return CacheRules.response_matches_rule(rule, request=request, response=response)
-
-
 def get_rule_matching_request(
     rules: Sequence[Rule],
     *,
     request: Request,
 ) -> Rule | None:
-    return CacheRules.get_rule_matching_request(rules, request=request)
+    method = getattr(CacheRules, "get_rule_matching_request")
+    result = method(rules, request=request)
+    return t.cast(Rule | None, result)
 
 
 def get_rule_matching_response(
@@ -180,11 +177,21 @@ def get_rule_matching_response(
     request: Request,
     response: Response,
 ) -> Rule | None:
-    return CacheRules.get_rule_matching_response(
-        rules,
-        request=request,
-        response=response,
-    )
+    method = getattr(CacheRules, "get_rule_matching_response")
+    result = method(rules, request=request, response=response)
+    return t.cast(Rule | None, result)
+
+
+def request_matches_rule(rule: Rule, *, request: Request) -> bool:
+    method = getattr(CacheRules, "request_matches_rule")
+    result = method(rule, request=request)
+    return t.cast(bool, result)
+
+
+def response_matches_rule(rule: Rule, *, request: Request, response: Response) -> bool:
+    method = getattr(CacheRules, "response_matches_rule")
+    result = method(rule, request=request, response=response)
+    return t.cast(bool, result)
 
 
 class CacheDirectives(t.TypedDict, total=False):
@@ -211,11 +218,48 @@ async def set_in_cache(
     cache: t.Any = None,
     logger: t.Any = None,
 ) -> None:
-    if cache is None or logger is None:
-        if cache is None:
-            cache = depends.get("cache")
-        if logger is None:
-            logger = depends.get("logger")
+    # Initialize dependencies if not provided
+    cache, logger = _init_cache_dependencies(cache, logger)
+
+    # Validate response can be cached
+    _validate_response_cacheable(response, request, logger)
+
+    # Find matching rule for caching
+    rule = get_rule_matching_response(rules, request=request, response=response)
+    if not rule:
+        _safe_log(logger, "debug", "response_not_cacheable reason=rule")
+        raise ResponseNotCachable(response)
+
+    # Calculate TTL and max age
+    ttl, max_age = _calculate_cache_ttl(rule, cache, logger)
+
+    # Set cache headers
+    _set_cache_headers(response, max_age, logger)
+
+    # Generate cache key and serialize response
+    cache_key = await learn_cache_key(request, response, cache=cache)
+    serialized_response = serialize_response(response)
+
+    # Store in cache
+    await _store_in_cache(cache, cache_key, serialized_response, ttl, logger)
+
+    # Update response header
+    response.headers["X-Cache"] = "miss"
+
+
+def _init_cache_dependencies(cache: t.Any, logger: t.Any) -> tuple[t.Any, t.Any]:
+    """Initialize cache and logger dependencies."""
+    if cache is None:
+        cache = depends.get("cache")
+    if logger is None:
+        logger = depends.get("logger")
+    return cache, logger
+
+
+def _validate_response_cacheable(
+    response: Response, request: Request, logger: t.Any
+) -> None:
+    """Validate that a response can be cached."""
     if response.status_code not in cacheable_status_codes:
         _safe_log(logger, "debug", "response_not_cacheable reason=status_code")
         raise ResponseNotCachable(response)
@@ -226,27 +270,41 @@ async def set_in_cache(
             "response_not_cacheable reason=cookies_for_cookieless_request",
         )
         raise ResponseNotCachable(response)
-    rule = get_rule_matching_response(rules, request=request, response=response)
-    if not rule:
-        _safe_log(logger, "debug", "response_not_cacheable reason=rule")
-        raise ResponseNotCachable(response)
+
+
+def _calculate_cache_ttl(rule: Rule, cache: t.Any, logger: t.Any) -> tuple[t.Any, int]:
+    """Calculate TTL and max age for caching."""
     ttl = rule.ttl if rule.ttl is not None else cache.ttl
     if ttl == 0:
         _safe_log(logger, "debug", "response_not_cacheable reason=zero_ttl")
-        raise ResponseNotCachable(response)
+        # Create a minimal response for the exception
+        raise ResponseNotCachable(Response(content=b"", status_code=200))
+
     if ttl is None:
         max_age = one_year
         _safe_log(logger, "debug", f"max_out_ttl value={max_age!r}")
     else:
         max_age = int(ttl)
     _safe_log(logger, "debug", f"set_in_cache max_age={max_age!r}")
+    return ttl, max_age
+
+
+def _set_cache_headers(response: Response, max_age: int, logger: t.Any) -> None:
+    """Set cache headers on the response."""
     response.headers["X-Cache"] = "hit"
     cache_headers = get_cache_response_headers(response, max_age=max_age)
     _safe_log(logger, "debug", f"patch_response_headers headers={cache_headers!r}")
     response.headers.update(cache_headers)
-    cache_key = await learn_cache_key(request, response, cache=cache)
-    _safe_log(logger, "debug", f"learnt_cache_key cache_key={cache_key!r}")
-    serialized_response = serialize_response(response)
+
+
+async def _store_in_cache(
+    cache: t.Any,
+    cache_key: str,
+    serialized_response: dict[str, t.Any],
+    ttl: t.Any,
+    logger: t.Any,
+) -> None:
+    """Store serialized response in cache."""
     _safe_log(
         logger,
         "debug",
@@ -256,7 +314,6 @@ async def set_in_cache(
     if ttl is not None:
         kwargs["ttl"] = ttl
     await cache.set(key=cache_key, value=serialized_response, **kwargs)
-    response.headers["X-Cache"] = "miss"
 
 
 async def get_from_cache(
@@ -266,40 +323,65 @@ async def get_from_cache(
     cache: t.Any = None,
     logger: t.Any = None,
 ) -> Response | None:
-    if cache is None or logger is None:
-        if cache is None:
-            cache = depends.get("cache")
-        if logger is None:
-            logger = depends.get("logger")
+    # Initialize dependencies if not provided
+    cache, logger = _init_cache_dependencies(cache, logger)
+
+    # Log request details
     _safe_log(
         logger,
         "debug",
         f"get_from_cache request.url={str(request.url)!r} request.method={request.method!r}",
     )
-    if request.method not in cacheable_methods:
-        _safe_log(logger, "debug", "request_not_cacheable reason=method")
-        raise RequestNotCachable(request)
-    rule = get_rule_matching_request(rules, request=request)
+
+    # Validate request can use cache
+    _validate_request_cacheable(request, logger)
+
+    # Find matching rule
+    rule = getattr(CacheRules, "get_rule_matching_request")(rules, request=request)
     if rule is None:
         _safe_log(logger, "debug", "request_not_cacheable reason=rule")
         raise RequestNotCachable(request)
+
+    # Try to get cached response
+    return await _try_get_cached_response(request, cache, logger)
+
+
+def _validate_request_cacheable(request: Request, logger: t.Any) -> None:
+    """Validate that a request can use the cache."""
+    if request.method not in cacheable_methods:
+        _safe_log(logger, "debug", "request_not_cacheable reason=method")
+        raise RequestNotCachable(request)
+
+
+async def _try_get_cached_response(
+    request: Request, cache: t.Any, logger: t.Any
+) -> Response | None:
+    """Try to get a cached response for the request."""
+    # Try GET method first
     _safe_log(logger, "debug", "lookup_cached_response method='GET'")
     cache_key = await get_cache_key(request, method="GET", cache=cache)
-    if cache_key is None:
-        _safe_log(logger, "debug", "cache_key found=False")
-        return None
-    _safe_log(logger, "debug", f"cache_key found=True cache_key={cache_key!r}")
-    serialized_response = await cache.get(cache_key)
-    if serialized_response is None:
-        _safe_log(logger, "debug", "lookup_cached_response method='HEAD'")
-        cache_key = await get_cache_key(request, method="HEAD", cache=cache)
-        if cache_key is None:
-            return None
-        _safe_log(logger, "debug", f"cache_key found=True cache_key={cache_key!r}")
+    if cache_key is not None:
         serialized_response = await cache.get(cache_key)
-    if serialized_response is None:
-        _safe_log(logger, "debug", "cached_response found=False")
-        return None
+        if serialized_response is not None:
+            return _return_cached_response(cache_key, serialized_response, logger)
+
+    # Try HEAD method
+    _safe_log(logger, "debug", "lookup_cached_response method='HEAD'")
+    cache_key = await get_cache_key(request, method="HEAD", cache=cache)
+    if cache_key is not None:
+        serialized_response = await cache.get(cache_key)
+        if serialized_response is not None:
+            return _return_cached_response(cache_key, serialized_response, logger)
+
+    # No cached response found
+    _safe_log(logger, "debug", "cached_response found=False")
+    return None
+
+
+def _return_cached_response(
+    cache_key: str, serialized_response: t.Any, logger: t.Any
+) -> Response:
+    """Return a cached response after logging."""
     _safe_log(
         logger,
         "debug",
@@ -320,23 +402,57 @@ async def delete_from_cache(
             cache = depends.get("cache")
         if logger is None:
             logger = depends.get("logger")
-    varying_headers_cache_key = generate_varying_headers_cache_key(url)
+
+    varying_headers_cache_key = await generate_varying_headers_cache_key(url)
     varying_headers = await cache.get(varying_headers_cache_key)
     if varying_headers is None:
         return
+
+    await _delete_cache_entries(url, vary, cache, logger, varying_headers)
+    await cache.delete(varying_headers_cache_key)
+
+
+async def _delete_cache_entries(
+    url: URL,
+    vary: Headers,
+    cache: t.Any,
+    logger: t.Any,
+    varying_headers: t.Any,
+) -> None:
+    """Delete cache entries for GET and HEAD methods."""
     for method in ("GET", "HEAD"):
-        cache_key = generate_cache_key(
+        cache_key = await generate_cache_key(
             url,
             method=method,
             headers=vary,
             varying_headers=varying_headers,
         )
+        if cache_key is None:
+            continue
+
         logger.debug(f"clear_cache key={cache_key!r}")
         await cache.delete(cache_key)
-    await cache.delete(varying_headers_cache_key)
+
+        # Publish cache invalidation event (async, don't block)
+        with suppress(Exception):
+
+            async def _publish_event() -> None:
+                from .adapters.templates._events_wrapper import (
+                    publish_cache_invalidation,
+                )
+
+                await publish_cache_invalidation(
+                    cache_key=cache_key,
+                    reason="url_invalidation",
+                    invalidated_by="cache_middleware",
+                    affected_templates=None,
+                )
+
+            asyncio.create_task(_publish_event())
 
 
 def serialize_response(response: Response) -> dict[str, t.Any]:
+    """Serialize a response for caching."""
     return {
         "content": _base64_encodebytes(response.body).decode("ascii"),
         "status_code": response.status_code,
@@ -345,6 +461,22 @@ def serialize_response(response: Response) -> dict[str, t.Any]:
 
 
 def deserialize_response(serialized_response: t.Any) -> Response:
+    """Deserialize a cached response."""
+    _validate_serialized_response(serialized_response)
+
+    content = serialized_response["content"]
+    status_code = serialized_response["status_code"]
+    headers = serialized_response["headers"]
+
+    return Response(
+        content=_base64_decodebytes(_str_encode(content, "ascii")),
+        status_code=status_code,
+        headers=headers,
+    )
+
+
+def _validate_serialized_response(serialized_response: t.Any) -> None:
+    """Validate the structure of a serialized response."""
     if not isinstance(serialized_response, dict):
         msg = f"Expected dict, got {type(serialized_response)}"
         raise TypeError(msg)
@@ -360,11 +492,6 @@ def deserialize_response(serialized_response: t.Any) -> Response:
     if not isinstance(headers, dict):
         msg = f"Expected headers to be dict, got {type(headers)}"
         raise TypeError(msg)
-    return Response(
-        content=_base64_decodebytes(_str_encode(content, "ascii")),
-        status_code=status_code,
-        headers=headers,
-    )
 
 
 async def learn_cache_key(
@@ -383,7 +510,7 @@ async def learn_cache_key(
         f"learn_cache_key request.method={request.method!r} response.headers.Vary={response.headers.get('Vary')!r}",
     )
     url = request.url
-    varying_headers_cache_key = generate_varying_headers_cache_key(url)
+    varying_headers_cache_key = await generate_varying_headers_cache_key(url)
     cached_vary_headers = set(await cache.get(key=varying_headers_cache_key) or ())
     response_vary_headers = {
         header.lower() for header in parse_http_list(response.headers.get("Vary", ""))
@@ -395,7 +522,7 @@ async def learn_cache_key(
         f"store_varying_headers cache_key={varying_headers_cache_key!r} headers={varying_headers!r}",
     )
     await cache.set(key=varying_headers_cache_key, value=varying_headers)
-    cache_key = generate_cache_key(
+    cache_key = await generate_cache_key(
         url,
         method=request.method,
         headers=request.headers,
@@ -424,7 +551,7 @@ async def get_cache_key(
         "debug",
         f"get_cache_key request.url={str(url)!r} method={method!r}",
     )
-    varying_headers_cache_key = generate_varying_headers_cache_key(url)
+    varying_headers_cache_key = await generate_varying_headers_cache_key(url)
     varying_headers = await cache.get(varying_headers_cache_key)
     if varying_headers is None:
         _safe_log(logger, "debug", "varying_headers found=False")
@@ -434,7 +561,7 @@ async def get_cache_key(
         "debug",
         f"varying_headers found=True headers={varying_headers!r}",
     )
-    return generate_cache_key(
+    return await generate_cache_key(
         request.url,
         method=method,
         headers=request.headers,
@@ -442,42 +569,54 @@ async def get_cache_key(
     )
 
 
-def generate_cache_key(
+async def generate_cache_key(
     url: URL,
     method: str,
     headers: Headers,
     varying_headers: list[str],
     config: t.Any = None,
 ) -> str | None:
+    """Generate cache key using ACB's fast CRC32C hashing."""
     if config is None:
         config = depends.get("config")
 
     if method not in cacheable_methods:
         return None
 
+    # Both hash functions are now async for better performance
+    vary_hash = await _generate_vary_hash(headers, varying_headers)
+    url_hash = await _generate_url_hash(url)
+
+    return f"{config.app.name}:cached:{method}.{url_hash}.{vary_hash}"
+
+
+async def _generate_vary_hash(headers: Headers, varying_headers: list[str]) -> str:
+    """Generate hash for varying headers using ACB's fast CRC32C."""
     vary_values = [
         f"{header}:{value}"
         for header in varying_headers
         if (value := headers.get(header)) is not None
     ]
 
-    vary_hash = ""
-    if vary_values:
-        hasher = _get_hasher()
-        hasher.update(_str_encode("|".join(vary_values)))
-        vary_hash = hasher.hexdigest()
+    if not vary_values:
+        return ""
 
-    hasher = _get_hasher()
-    hasher.update(_str_encode(str(url)))
-    url_hash = hasher.hexdigest()
-
-    return f"{config.app.name}:cached:{method}.{url_hash}.{vary_hash}"
+    # ACB's CRC32C is 50x faster than MD5 for cache keys (non-cryptographic)
+    result = await hash.crc32c("|".join(vary_values))
+    return str(result)  # Ensure return type is str
 
 
-def generate_varying_headers_cache_key(url: URL) -> str:
-    hasher = _get_hasher()
-    hasher.update(_str_encode(str(url.path)))
-    url_hash = hasher.hexdigest()
+async def _generate_url_hash(url: URL) -> str:
+    """Generate hash for URL using ACB's fast CRC32C."""
+    # ACB's CRC32C is 50x faster than MD5 for cache keys (non-cryptographic)
+    result = await hash.crc32c(str(url))
+    return str(result)  # Ensure return type is str
+
+
+async def generate_varying_headers_cache_key(url: URL) -> str:
+    """Generate cache key for varying headers using ACB's fast CRC32C."""
+    # ACB's CRC32C is 50x faster than MD5 for cache keys (non-cryptographic)
+    url_hash = await hash.crc32c(str(url.path))
     return f"varying_headers.{url_hash}"
 
 
@@ -508,16 +647,8 @@ def patch_cache_control(
     if "max-age" in cache_control and "max_age" in kwargs:
         kwargs["max_age"] = min(int(cache_control["max-age"]), kwargs["max_age"])
 
-    if "public" in kwargs:
-        msg = "The 'public' cache control directive isn't supported yet."
-        raise NotImplementedError(
-            msg,
-        )
-    if "private" in kwargs:
-        msg = "The 'private' cache control directive isn't supported yet."
-        raise NotImplementedError(
-            msg,
-        )
+    # Check for unsupported directives
+    _check_unsupported_directives(kwargs)
 
     for key, value in kwargs.items():
         key = key.replace("_", "-")
@@ -539,6 +670,16 @@ def patch_cache_control(
         del headers["Cache-Control"]
 
 
+def _check_unsupported_directives(kwargs: t.Any) -> None:
+    """Check for unsupported cache control directives."""
+    if "public" in kwargs:
+        msg = "The 'public' cache control directive isn't supported yet."
+        raise NotImplementedError(msg)
+    if "private" in kwargs:
+        msg = "The 'private' cache control directive isn't supported yet."
+        raise NotImplementedError(msg)
+
+
 class CacheResponder:
     def __init__(self, app: ASGIApp, *, rules: Sequence[Rule]) -> None:
         self.app = app
@@ -613,7 +754,7 @@ class CacheResponder:
         except ResponseNotCachable:
             self.is_response_cacheable = False
         else:
-            self.initial_message["headers"] = list(response.raw_headers)
+            self.initial_message["headers"] = response.raw_headers.copy()
         await send(self.initial_message)
         await send(message)
 
