@@ -3,6 +3,8 @@
 from dataclasses import dataclass
 from typing import Any
 
+import pytest
+
 # FastBlocks has its own HTMY implementation, doesn't use the htmy library
 Component = Any
 Context = dict
@@ -16,6 +18,7 @@ HTMY_AVAILABLE = False
 
 
 @dataclass
+@pytest.mark.unit
 class TestCard:
     """Simple test card component for FastBlocks HTMY integration."""
 
