@@ -2,11 +2,14 @@ from pathlib import Path
 
 import pytest
 
+# Get project root dynamically
+PROJECT_ROOT = Path(__file__).parent.parent
+
 
 @pytest.mark.unit
 class TestCLIStructure:
     def test_cli_module_structure(self) -> None:
-        cli_file_path = "/Users/les/Projects/fastblocks/fastblocks/cli.py"
+        cli_file_path = PROJECT_ROOT / "fastblocks/cli.py"
 
         source_code = Path(cli_file_path).read_text()
 
