@@ -11,18 +11,18 @@ with patch("fastblocks.htmx.debug") as mock_debug:
     mock_debug.enabled = False
     from fastblocks.htmx import (
         HtmxDetails,
-        HtmxRequest,
         HtmxResponse,
         _get_header,
-        htmx_trigger,
+        htmx_push_url,
         htmx_redirect,
         htmx_refresh,
-        htmx_push_url,
         htmx_retarget,
+        htmx_trigger,
         is_htmx,
     )
 
 
+@pytest.mark.unit
 class TestHtmxDetails:
     """Test HtmxDetails class."""
 
@@ -338,6 +338,7 @@ class TestHtmxDetails:
             assert value is None
 
 
+@pytest.mark.unit
 class TestHtmxResponse:
     """Test HtmxResponse class."""
 
@@ -417,6 +418,7 @@ class TestHtmxResponse:
         assert response.headers["HX-Location"] == "/new-page"
 
 
+@pytest.mark.unit
 class TestHtmxHelpers:
     """Test HTMX helper functions."""
 
@@ -460,11 +462,13 @@ class TestHtmxHelpers:
         assert response.body == b"<div>New content</div>"
 
 
+@pytest.mark.unit
 class TestIsHtmx:
     """Test is_htmx function."""
 
     def test_is_htmx_with_request_object(self) -> None:
         """Test is_htmx with request-like object."""
+
         class MockRequest:
             def __init__(self, is_htmx: bool) -> None:
                 self.headers = {"HX-Request": "true" if is_htmx else "false"}
